@@ -1,4 +1,4 @@
-# PiTiVi , Non-linear video editor
+# Pitivi video editor
 #
 #       configure.py
 #
@@ -26,9 +26,11 @@ Enables identical use for installed and uninstalled versions.
 import os.path
 
 
+# Again, mostly the same thing as in bin/pitivi.in and pitivi/utils/misc.py:
 def _get_root_dir():
     return '/'.join(os.path.dirname(os.path.abspath(__file__)).split('/')[:-1])
 
+
 def _in_devel():
     rd = _get_root_dir()
     return os.path.exists(os.path.join(rd, '.git'))
@@ -36,22 +38,17 @@ def _in_devel():
 
 LIBDIR = '/usr/local/lib'
 PKGDATADIR = '/usr/local/share/pitivi'
-pitivi_version = '0.15.2'
-APPNAME = 'PiTiVi'
+pitivi_version = '0.91'
+APPNAME = 'Pitivi'
 APPURL = 'http://www.pitivi.org/'
-PYGTK_REQ = '2.17.0'
-GTK_REQ = '2.24.0'
-PYGST_REQ = '0.10.19'
-GST_REQ = '0.10.28'
-GNONLIN_REQ = '0.10.16'
-PYCAIRO_REQ = '1.0.0'
+RELEASES_URL = 'http://pitivi.org/releases.txt'
+APPMANUALURL_ONLINE = 'http://www.pitivi.org/manual'
+
 
 if _in_devel():
     APPMANUALURL_OFFLINE = 'ghelp://%s' % os.path.join(_get_root_dir(), 'help/C')
 else:
-    APPMANUALURL_OFFLINE = 'ghelp:pitivi'
-
-APPMANUALURL_ONLINE = 'http://www.pitivi.org/manual'
+    APPMANUALURL_OFFLINE = 'help:pitivi'
 
 
 def get_data_dir():
@@ -64,22 +61,27 @@ def get_data_dir():
         datadir = PKGDATADIR
     return os.path.abspath(datadir)
 
+
 def get_pixmap_dir():
     """ Returns the directory for program-only pixmaps """
     return os.path.join(get_data_dir(), 'pixmaps')
 
+
 def get_ui_dir():
     """ Returns the directory for GtkBuilder/Glade files """
     return os.path.join(get_data_dir(), 'ui')
 
+
 def get_renderpresets_dir():
     """ Returns the directory for Render Presets files """
     return os.path.join(get_data_dir(), 'renderpresets')
 
+
 def get_audiopresets_dir():
     """ Returns the directory for Audio Presets files """
     return os.path.join(get_data_dir(), 'audiopresets')
 
+
 def get_videopresets_dir():
     """ Returns the directory for Video Presets files """
     return os.path.join(get_data_dir(), 'videopresets')
